@@ -20,7 +20,8 @@ from collections import OrderedDict
 class Paths:
     def __init__(self, appname: str, inifile: str = None) -> None:
         """
-        A class to hold the default paths for the application
+        A class to hold the default paths for the application. These values are
+        all determined from the installation location of the calling script.
 
         If the `data` is needed, it must be created manually to avoid unnecessary
         data directories.
@@ -50,20 +51,24 @@ class Paths:
         self.top = os.path.join(self.root, "scripts", basename)
         """The location of the application scripts: `root/scripts/app`"""
         self.module_config_dir = self.get_module_config_dir()
-        """The location of the module ini, key and env files"""
+        """The location of the `keyfile`, `local_env` and `local_config` files"""
         self.keyfile = os.path.join(self.module_config_dir, "key")
         """The file from where to obtain the key: `~/.config/alx/key` or
-        `%APPDATA%\\alx\\key` on Windows"""
+        `%APPDATA%\\alx\\key` on Windows. This file holds the `cryptography`
+        key for use with `ALXapp.decrypt` and `ALXapp.encrypt`"""
         self.local_env = os.path.join(self.module_config_dir, "env")
-        """The path to the venv in use: `~/.config/alx/env`"""
+        """The path to the environment to be used in use: `~/.config/alx/env`.
+        Typically it only holds the python venv to be used:
+        - `venv=/path/to/venv/current`"""
         self.local_config = os.path.join(self.module_config_dir, "alx.ini")
-        """The path to the local configuration: `~/.config/alx/alx.ini`"""
+        """The path to the local configuration: `~/.config/alx/alx.ini`. Entries
+        in this file will override those of the global configuration"""
         self.global_config = os.path.join(
             os.path.dirname(os.path.abspath(__file__)), "alx.ini")
         """The path to the module configuration: `<venv>/lib/.../site-packages/alx/alx.ini`"""
 
         self.config = os.path.join(self.etc, appname + ".ini")
-        """The name of the config file determined from `self.etc`/app"""
+        """The name of the config file determined from `self.etc/app.ini`"""
         if inifile:
             self.config = os.path.join(self.etc, inifile)
 
@@ -74,6 +79,40 @@ class Paths:
         else:
             return os.path.join(os.path.expanduser("~"), ".config", "alx")
 
+    def create_configuration_files(self) -> None:
+        """
+        Create some initial configuration files under `module_config_dir`.
+        Descriptions of the files are above:
+        - `local_env`
+        - `local_config`
+        - `keyfile`
+
+        :return: None
+        """
+        os.makedirs(self.module_config_dir, exist_ok=True)
+
+        if not os.path.isfile(self.local_config):
+            print("*** NOTE: Creating user config file '{}'".format(self.local_config))
+            gc = ALXapp.read_config(self.global_config)
+            with open(self.local_config, 'w') as f:
+                for s in gc.sections():
+                    f.write("[%s]\n\n" % s)
+
+        if not os.path.isfile(self.keyfile):
+            print("*** NOTE: Creating key file '{}'".format(self.keyfile))
+            # Create an initial fernet key.  User to adjust as required
+            with open(self.keyfile, 'w') as f:
+                f.write("%s\n" % Fernet.generate_key().decode())
+            # Ensure strict permissions
+            os.chmod(self.keyfile, 0o600)
+
+        if not os.path.isfile(self.local_env):
+            print("*** NOTE: Creating local environment file: '{}'".format(self.local_env))
+            # Assume that the current python invocation is the path to the virtual env
+            with open(self.local_env, 'w') as f:
+                venv = os.path.dirname(os.path.dirname(sys.executable))
+                f.write("venv=%s\n" % venv)
+
     def __str__(self) -> str:
         return "\n".join(f"{k}: {v}" for k, v in vars(self).items() if isinstance(v, str))
 
@@ -335,36 +374,6 @@ class ALXapp:
 
         return config
 
-    def _create_configuration_files(self) -> None:
-        """
-        Create some initial configuration files
-
-        :return: None
-        """
-        os.makedirs(self.paths.module_config_dir, exist_ok=True)
-
-        if not os.path.isfile(self.paths.local_config):
-            print("*** NOTE: Creating user config file '{}'".format(self.paths.local_config))
-            gc = ALXapp.read_config(self.paths.global_config)
-            with open(self.paths.local_config, 'w') as f:
-                for s in gc.sections():
-                    f.write("[%s]\n\n" % s)
-
-        if not os.path.isfile(self.paths.keyfile):
-            print("*** NOTE: Creating key file '{}'".format(self.paths.keyfile))
-            # Create an initial fernet key.  User to adjust as required
-            with open(self.paths.keyfile, 'w') as f:
-                f.write("%s\n" % Fernet.generate_key().decode())
-            # Ensure strict permissions
-            os.chmod(self.paths.keyfile, 0o600)
-
-        if not os.path.isfile(self.paths.local_env):
-            print("*** NOTE: Creating local environment file: '{}'".format(self.paths.local_env))
-            # Assume that the current python invocation is the path to the virtual env
-            with open(self.paths.local_env, 'w') as f:
-                venv = os.path.dirname(os.path.dirname(sys.executable))
-                f.write("venv=%s\n" % venv)
-
     def read_lib_config(self) -> configparser.ConfigParser:
         """
         Reads and parses the module configuration file and the local
@@ -381,12 +390,7 @@ class ALXapp:
             self.paths = Paths("alx-common")
 
         # If the user configuration doesn't exist, create them
-        if not all([
-            os.path.isdir(self.paths.module_config_dir),
-            os.path.isfile(self.paths.local_config),
-            os.path.isfile(self.paths.keyfile),
-            os.path.isfile(self.paths.local_env),]):
-            self._create_configuration_files()
+        self.paths.create_configuration_files()
 
         merged_config = ALXapp.read_config(self.paths.global_config,
                                            self.paths.local_config)
